Installation
============
Omnipath requires Python version >= 3.7 to run.

PyPI
~~~~
Omnipath is also available on PyPI::

    pip install omnipath

Additionally, :mod:`omnipath` may sometimes require :mod:`networkx` to create an interaction graph.
This dependency can be installed as::

    pip install omnipath[graph]

Development Version
~~~~~~~~~~~~~~~~~~~
To stay up-to-date with the newest version, run::

    pip install git+https://github.com/saezlab/omnipath
